#  Build CRUD gRPC Server API & Client with Golang and MongoDB

In this article, you'll learn how to build a CRUD gRPC API server with Golang, MongoDB-Go-driver, and Docker-compose. You'll also build a gRPC client to interact with the gRPC API.

![Build CRUD gRPC Server API & Client with Golang and MongoDB](https://codevoweb.com/wp-content/uploads/2022/06/Build-CRUD-gRPC-Server-API-Client-with-Golang-and-MongoDB.webp)

## Topics Covered

- Define the Models with Structs
- Create the ProtoBuf Messages
- Define the gRPC Service and RPC Methods
- Define a Custom Service Interface
- Create Methods to Implement the Service Interface
    - Create a Constructor to Implement the Service Interface
    - Create a new Post
    - Update a Post
    - Find a Post
    - Retrieve All Posts
    - Delete a Post
- Define the gRPC Controllers
- Register the gRPC Services and Start the gRPC Server
- Test the gRPC API Server with Evans CLI
- Create the gRPC API Handlers in Golang
    - CreatePost gRPC Handler
    - UpdatePost gRPC Service Handler
    - GetPost gRPC Service Handler 
    - DeletePost gRPC Service Handler
    - GetPosts gRPC Service Handler
- Testing the gRPC Services with Evans Cli
- Create the gRPC Clients
    - gRPC Client to Create a Post
    - gRPC Client to Update a Post
    - gRPC Client to Get a Single Post
    - gRPC Client to Get All Posts
    - gRPC Client to Delete a Post
- Register the gRPC Services

Read the entire article here: [https://codevoweb.com/crud-grpc-server-api-client-with-golang-and-mongodb](https://codevoweb.com/crud-grpc-server-api-client-with-golang-and-mongodb)

Articles in this series:

### 1. API with Golang + MongoDB + Redis + Gin Gonic: Project Setup

[API with Golang + MongoDB + Redis + Gin Gonic: Project Setup](https://codevoweb.com/api-golang-mongodb-gin-gonic-project-setup)

### 2. Golang & MongoDB: JWT Authentication and Authorization

[Golang & MongoDB: JWT Authentication and Authorization](https://codevoweb.com/golang-mongodb-jwt-authentication-authorization)

### 3. API with Golang + MongoDB: Send HTML Emails with Gomail

[API with Golang + MongoDB: Send HTML Emails with Gomail](https://codevoweb.com/api-golang-mongodb-send-html-emails-gomail)

### 4. API with Golang, Gin Gonic & MongoDB: Forget/Reset Password

[API with Golang, Gin Gonic & MongoDB: Forget/Reset Password](https://codevoweb.com/api-golang-gin-gonic-mongodb-forget-reset-password)

### 5. Build Golang gRPC Server and Client: SignUp User & Verify Email

[Build Golang gRPC Server and Client: SignUp User & Verify Email](https://codevoweb.com/golang-grpc-server-and-client-signup-user-verify-email)

### 6. Build Golang gRPC Server and Client: Access & Refresh Tokens

[Build Golang gRPC Server and Client: Access & Refresh Tokens](https://codevoweb.com/golang-grpc-server-and-client-access-refresh-tokens)

### 7. Build CRUD RESTful API Server with Golang, Gin, and MongoDB

[Build CRUD RESTful API Server with Golang, Gin, and MongoDB](https://codevoweb.com/crud-restful-api-server-with-golang-and-mongodb)

### 8. Build CRUD gRPC Server API & Client with Golang and MongoDB

[Build CRUD gRPC Server API & Client with Golang and MongoDB](https://codevoweb.com/crud-grpc-server-api-client-with-golang-and-mongodb)
